@@ -10,10 +10,11 @@ fn fixture_path(name: &str) -> PathBuf {
 }
 
 fn default_options() -> ConversionOptions {
-    let mut options = ConversionOptions::default();
-    options.extract_metadata = false;
-    options.autolinks = false;
-    options
+    ConversionOptions {
+        extract_metadata: false,
+        autolinks: false,
+        ..Default::default()
+    }
 }
 
 fn normalize_newlines(input: &str) -> String {
